*********
LLM Cache
*********

SemanticCache
=============

.. _semantic_cache_api:

.. currentmodule:: redisvl.extensions.cache.llm

.. autoclass:: SemanticCache
   :show-inheritance:
   :members:
   :inherited-members:


Cache Schema Classes
====================

CacheEntry
----------

.. _cache_entry_api:

.. currentmodule:: redisvl.extensions.cache.llm.schema

.. autoclass:: CacheEntry
   :members:
   :show-inheritance:

CacheHit
--------

.. _cache_hit_api:

.. currentmodule:: redisvl.extensions.cache.llm.schema

.. autoclass:: CacheHit
   :members:
   :show-inheritance:


****************
Embeddings Cache
****************

EmbeddingsCache
===============

.. _embeddings_cache_api:

.. currentmodule:: redisvl.extensions.cache.embeddings

.. autoclass:: EmbeddingsCache
   :show-inheritance:
   :members:
   :inherited-members:
